@@ -9,11 +9,11 @@
 
 #include "multifilecache.h"
 #include "singlefilecache.h"
+#include <KLocalizedString>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QStringList>
 #include <interfaces/cachefactory.h>
-#include <klocalizedstring.h>
-#include <qstringlist.h>
 #include <torrent/torrent.h>
 #include <util/array.h>
 #include <util/bitset.h>
@@ -24,6 +24,8 @@
 #include <util/log.h>
 #include <util/timer.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 Uint32 ChunkManager::preview_size_audio = 256 * 1024; // 256 KB for audio files
@@ -91,9 +93,9 @@ QString ChunkManager::getDataDir() const
 void ChunkManager::changeDataDir(const QString &data_dir)
 {
     d->cache->changeTmpDir(data_dir);
-    d->index_file = data_dir + "index";
-    d->file_info_file = data_dir + "file_info";
-    d->file_priority_file = data_dir + "file_priority";
+    d->index_file = data_dir + "index"_L1;
+    d->file_info_file = data_dir + "file_info"_L1;
+    d->file_priority_file = data_dir + "file_priority"_L1;
 }
 
 void ChunkManager::changeOutputPath(const QString &output_path)
@@ -125,7 +127,7 @@ void ChunkManager::createFiles(bool check_priority)
 {
     if (!bt::Exists(d->index_file)) {
         File fptr;
-        fptr.open(d->index_file, "wb");
+        fptr.open(d->index_file, u"wb"_s);
     }
     d->cache->create();
 
@@ -186,7 +188,7 @@ void ChunkManager::resetChunk(unsigned int i)
     bitset.set(i, false);
     d->todo.set(i, !excluded_chunks.get(i) && !only_seed_chunks.get(i));
     tor.updateFilePercentage(i, *this);
-    Out(SYS_DIO | LOG_DEBUG) << QString("Reset chunk %1").arg(i) << endl;
+    Out(SYS_DIO | LOG_DEBUG) << u"Reset chunk %1"_s.arg(i) << endl;
 }
 
 void ChunkManager::checkMemoryUsage()
@@ -412,7 +414,7 @@ void ChunkManager::Private::savePriorityInfo()
     // save priority info and call saveFileInfo
     saveFileInfo();
     File fptr;
-    if (!fptr.open(file_priority_file, "wb")) {
+    if (!fptr.open(file_priority_file, u"wb"_s)) {
         Out(SYS_DIO | LOG_IMPORTANT) << "Warning : Can not save chunk_info file : " << fptr.errorString() << endl;
         return;
     }
@@ -446,7 +448,7 @@ void ChunkManager::Private::loadPriorityInfo()
 {
     // load priority info and if that fails load file info
     File fptr;
-    if (!fptr.open(file_priority_file, "rb")) {
+    if (!fptr.open(file_priority_file, u"rb"_s)) {
         loadFileInfo();
         return;
     }
@@ -845,7 +847,7 @@ void ChunkManager::Private::setupPriorities()
 void ChunkManager::Private::saveIndexFile()
 {
     File fptr;
-    if (!fptr.open(index_file, "wb"))
+    if (!fptr.open(index_file, u"wb"_s))
         throw Error(i18n("Cannot open index file %1: %2", index_file, fptr.errorString()));
 
     for (unsigned int i = 0; i < p->getNumChunks(); i++) {
@@ -862,12 +864,12 @@ void ChunkManager::Private::saveIndexFile()
 void ChunkManager::Private::writeIndexFileEntry(Chunk *c)
 {
     File fptr;
-    if (!fptr.open(index_file, "r+b")) {
+    if (!fptr.open(index_file, u"r+b"_s)) {
         // no index file, so assume it's empty
         bt::Touch(index_file, true);
         Out(SYS_DIO | LOG_IMPORTANT) << "Can not open index file : " << fptr.errorString() << endl;
         // try again
-        if (!fptr.open(index_file, "r+b"))
+        if (!fptr.open(index_file, u"r+b"_s))
             // panick if it failes
             throw Error(i18n("Cannot open index file %1: %2", index_file, fptr.errorString()));
     }
@@ -884,7 +886,7 @@ void ChunkManager::Private::loadIndexFile()
     loadPriorityInfo();
 
     File fptr;
-    if (!fptr.open(index_file, "rb")) {
+    if (!fptr.open(index_file, u"rb"_s)) {
         // no index file, so assume it's empty
         bt::Touch(index_file, true);
         Out(SYS_DIO | LOG_IMPORTANT) << "Can not open index file : " << fptr.errorString() << endl;
@@ -918,7 +920,7 @@ void ChunkManager::Private::saveFileInfo()
 
     // saves which TorrentFiles do not need to be downloaded
     File fptr;
-    if (!fptr.open(file_info_file, "wb")) {
+    if (!fptr.open(file_info_file, u"wb"_s)) {
         Out(SYS_DIO | LOG_IMPORTANT) << "Warning : Can not save chunk_info file : " << fptr.errorString() << endl;
         return;
     }
@@ -946,7 +948,7 @@ void ChunkManager::Private::saveFileInfo()
 void ChunkManager::Private::loadFileInfo()
 {
     File fptr;
-    if (!fptr.open(file_info_file, "rb"))
+    if (!fptr.open(file_info_file, u"rb"_s))
         return;
 
     Uint32 num = 0, tmp = 0;
@@ -1013,31 +1015,31 @@ void ChunkManager::Private::dumpPriority(TorrentFile *tf)
         QString prio;
         switch (chunks[i]->getPriority()) {
         case FIRST_PREVIEW_PRIORITY:
-            prio = "First (Preview)";
+            prio = u"First (Preview)"_s;
             break;
         case FIRST_PRIORITY:
-            prio = "First";
+            prio = u"First"_s;
             break;
         case NORMAL_PREVIEW_PRIORITY:
-            prio = "Normal (Preview)";
+            prio = u"Normal (Preview)"_s;
             break;
         case NORMAL_PRIORITY:
-            prio = "Normal";
+            prio = u"Normal"_s;
             break;
         case LAST_PREVIEW_PRIORITY:
-            prio = "Last (Preview)";
+            prio = u"Last (Preview)"_s;
             break;
         case LAST_PRIORITY:
-            prio = "Last";
+            prio = u"Last"_s;
             break;
         case ONLY_SEED_PRIORITY:
-            prio = "Only Seed";
+            prio = u"Only Seed"_s;
             break;
         case EXCLUDED:
-            prio = "Excluded";
+            prio = u"Excluded"_s;
             break;
         default:
-            prio = "(invalid)";
+            prio = u"(invalid)"_s;
             break;
         }
         Out(SYS_DIO | LOG_DEBUG) << i << " prio " << prio << endl;
