@@ -4,13 +4,13 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "udptrackersocket.h"
+#include <KLocalizedString>
 #include <QHostAddress>
-#include <klocalizedstring.h>
+#include <cstdlib>
+#include <ctime>
 #include <net/portlist.h>
 #include <net/serversocket.h>
 #include <net/socket.h>
-#include <stdlib.h>
-#include <time.h>
 #include <torrent/globals.h>
 #include <util/array.h>
 #include <util/functions.h>
@@ -20,6 +20,8 @@
 #undef ERROR
 #endif
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 Uint16 UDPTrackerSocket::port = 4444;
@@ -102,7 +104,7 @@ UDPTrackerSocket::UDPTrackerSocket()
     }
 
     if (d->sockets.count() == 0) {
-        Out(SYS_TRK | LOG_IMPORTANT) << QString("Cannot bind to udp port %1").arg(port) << endl;
+        Out(SYS_TRK | LOG_IMPORTANT) << u"Cannot bind to udp port %1"_s.arg(port) << endl;
     } else {
         Globals::instance().getPortList().addNewPort(port, net::UDP, true);
     }
@@ -208,7 +210,7 @@ void UDPTrackerSocket::handleError(bt::Buffer::Ptr buf)
     d->transactions.erase(it);
     QString msg;
     for (Uint32 i = 8; i < buf->size(); i++)
-        msg += (char)buf->get()[i];
+        msg += QLatin1Char(buf->get()[i]);
 
     // emit signal
     Q_EMIT error(tid, msg);
